pub struct DueDate {
pub string: String,
pub date: NaiveDate,
pub is_recurring: bool,
pub exact: Option<ExactTime>,
}Expand description
DueDate is the Due object from the Todoist API.
Mostly contains human-readable content for easier display.
Fields
string: StringHuman-redable form of the due date.
date: NaiveDateThe date on which the Task is due.
is_recurring: boolLets us know if it is recurring (reopens after close).
exact: Option<ExactTime>If set, this shows the exact time the task is due.