Module tree

Module tree 

Maps Todoist API elements to the Tree that they represent.

Todoist API items have their own ID and sometimes a parent ID. Using this information we can construct a tree of items and their subitems. This is just a dirty implementation to get a tree data structure out of that.

Structs

Tree
Tree is a representation of Items as a tree.

Traits

TreeFlattenExt
Extension Trait to provide some additional common functionality for vectors of Trees.
Treeable
Treeable allows to make trees out of an ID and parent IDs.